Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9)

Unified Diff: ui/gfx/image/image_skia.h

Issue 2922463002: Replace deprecated base::NonThreadSafe in ui\gfx\image_skia.cc in favor of SequenceChecker. (Closed)
Patch Set: Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ui/gfx/image/image_skia.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/gfx/image/image_skia.h
diff --git a/ui/gfx/image/image_skia.h b/ui/gfx/image/image_skia.h
index 92fabe50ac1351c3a144358bb3061fa5f1bbd711..3e517c62db0339f0d2aa70bab098417b43b52dc4 100644
--- a/ui/gfx/image/image_skia.h
+++ b/ui/gfx/image/image_skia.h
@@ -112,16 +112,16 @@ class GFX_EXPORT ImageSkia {
// Make the ImageSkia instance read-only. Note that this only prevent
// modification from client code, and the storage may still be
// modified by the source if any (thus, it's not thread safe). This
// detaches the storage from currently accessing thread, so its safe
// to pass it to other thread as long as it is accessed only by that
// thread. If this ImageSkia's storage will be accessed by multiple
// threads, use |MakeThreadSafe()| method.
void SetReadOnly();
// Make the image thread safe by making the storage read only and remove
// its source if any. All ImageSkia that shares the same storage will also
// become thread safe. Note that in order to make it 100% thread safe,
// this must be called before it's been passed to anther thread.
void MakeThreadSafe();
bool IsThreadSafe() const;
@@ -166,13 +166,13 @@ class GFX_EXPORT ImageSkia {
const SkBitmap& GetBitmap() const;
// Checks if the current thread can read/modify the ImageSkia.
bool CanRead() const;
bool CanModify() const;
- // Detach the storage from the currently assinged thread
- // so that other thread can access the storage.
- void DetachStorageFromThread();
+ // Detach the storage from the currently assigned sequence
+ // so that other sequence can access the storage.
+ void DetachStorageFromSequence();
// A refptr so that ImageRepSkia can be copied cheaply.
scoped_refptr<internal::ImageSkiaStorage> storage_;
« no previous file with comments | « no previous file | ui/gfx/image/image_skia.cc » ('j') | no next file with comments »
@@ -112,16 +112,16 @@ class GFX_EXPORT ImageSkia {
// modification from client code, and the storage may still be
// modified by the source if any (thus, it's not thread safe). This
- // detaches the storage from currently accessing thread, so its safe
- // to pass it to other thread as long as it is accessed only by that
- // thread. If this ImageSkia's storage will be accessed by multiple
- // threads, use |MakeThreadSafe()| method.
+ // detaches the storage from currently accessing sequence, so its safe
+ // to pass it to another sequence as long as it is accessed only by that
+ // sequence. If this ImageSkia's storage will be accessed by multiple
+ // sequences, use |MakeThreadSafe()| method.
void SetReadOnly();
// Make the image thread safe by making the storage read only and remove
@@ -112,16 +112,16 @@ class GFX_EXPORT ImageSkia {
// its source if any. All ImageSkia that shares the same storage will also
// become thread safe. Note that in order to make it 100% thread safe,
- // this must be called before it's been passed to anther thread.
+ // this must be called before it's been passed to another sequence.
void MakeThreadSafe();
bool IsThreadSafe() const;
@@ -166,13 +166,13 @@ class GFX_EXPORT ImageSkia {
const SkBitmap& GetBitmap() const;
- // Checks if the current thread can read/modify the ImageSkia.
+ // Checks if the current sequence can read/modify the ImageSkia.
bool CanRead() const;
bool CanModify() const;

Powered by Google App Engine
This is Rietveld 408576698